==> astk-serveur-1.5.2.1.tbz: aster/ASTK/ASTK_SERV/lib/as_etude.py <==
# -*- coding: iso-8859-1 -*-

# ==============================================================================
# COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ==============================================================================

"""
Insert an execution into a database.
"""

__revision__ = "$Id: $"


# ----- differ messages translation
def _(mesg):
   return mesg

import os
import os.path
import getpass

#-------------------------------------------------------------------------------
def SetParser(run):
   """Configure the command-line parser, add options name to store to the list,
   set actions informations.
   run : ASTER_RUN object which manages the execution
   """
   acts_descr = {
      'insert_in_db' : {
         'method' : Insert,
         'syntax' : 'insert_in_db [export_file]',
         'help'   : 'prepare the profile to insert an execution into a database.'
      },
   }
   #opts_descr = {}
   title = 'Options for astketud database link'
   run.SetActions(
         actions_descr=acts_descr,
         actions_order=['insert_in_db'],
         group_options=False, group_title=title, actions_group_title=False,
         #options_descr=opts_descr,
   )

#-------------------------------------------------------------------------------
def Insert(run, *args):
   """Insert an execution to the database.
   """
   if len(args) != 1:
      run.parser.error(_("'--%s' takes exactly %d arguments (%d given)") % \
         (run.current_action, 1, len(args)))

   iret = 0
   on_machref = run.get('rep_agla', 'local') != 'local'
   if not on_machref:
      run.Mess(_('Only available on the AGLA machine'), _('<F>_AGLA_ERROR'))
   
   # 1. copy export file
   jn = run['num_job']
   fprof = os.path.join(run['tmp_user'], 'etude_prof.'+jn)
   kret = run.Copy(fprof, args[0], niverr=_('<F>_PROFILE_COPY'))

   # 2. insert study in database
   cmd = '%(astketud)s -U %(login)s %(profile)s' % {
      'astketud' : run['astketud'],
      'login'    : getpass.getuser(),
      'profile'  : fprof,
   }
   iret, output = run.Shell(cmd)
   if iret != 0:
      run.Mess(output, _('<F>_DB_ERROR'))

==> astk-serveur-1.7.1.1.tbz: aster/ASTK/ASTK_SERV/lib/as_etude.py <==
# -*- coding: iso-8859-1 -*-

# ==============================================================================
# COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ==============================================================================

"""
Insert an execution into a database.
"""

__revision__ = "$Id: as_etude.py 3750 2009-01-15 15:50:06Z courtois $"


# ----- differ messages translation
def _(mesg):
   return mesg

import os
import os.path
import getpass

#-------------------------------------------------------------------------------
def SetParser(run):
   """Configure the command-line parser, add options name to store to the list,
   set actions informations.
   run : ASTER_RUN object which manages the execution
   """
   acts_descr = {
      'insert_in_db' : {
         'method' : Insert,
         'syntax' : 'insert_in_db [export_file]',
         'help'   : 'prepare the profile to insert an execution into a database.'
      },
   }
   #opts_descr = {}
   title = 'Options for astketud database link'
   run.SetActions(
         actions_descr=acts_descr,
         actions_order=['insert_in_db'],
         group_options=False, group_title=title, actions_group_title=False,
         #options_descr=opts_descr,
   )

#-------------------------------------------------------------------------------
def Insert(run, *args):
   """Insert an execution to the database.
   """
   if len(args) != 1:
      run.parser.error(_("'--%s' takes exactly %d arguments (%d given)") % \
         (run.current_action, 1, len(args)))

   iret = 0
   on_machref = run.get('rep_agla', 'local') != 'local'
   if not on_machref:
      run.Mess(_('Only available on the AGLA machine'), _('<F>_AGLA_ERROR'))
   if not run.config.get('astketud'):
      run.Mess(_("'astketud' is not defined in 'config' file."), _('<F>_AGLA_ERROR'))
   
   # 1. copy export file
   jn = run['num_job']
   fprof = os.path.join(run['tmp_user'], 'etude_prof.'+jn)
   kret = run.Copy(fprof, args[0], niverr=_('<F>_PROFILE_COPY'))

   # 2. insert study in database
   cmd = '%(astketud)s %(profile)s' % {
      'astketud' : run['astketud'],
      'profile'  : fprof,
   }
   iret, output = run.Shell(cmd)
   if iret != 0:
      run.Mess(output, _('<F>_DB_ERROR'))
   # astketud always returns exit=0 !
   else:
      print output
